@@ -30,7 +30,10 @@ public:
                                                ElisaUtils::FilterByRecentlyPlayed,
                                                ElisaUtils::Track,
                                                DataTypes::LastPlayDate,
+                                               {DataTypes::LastPlayDate},
+                                               {i18n("Last Played Date")},
                                                Qt::DescendingOrder,
+                                               {i18n("Least Recently Played First"), i18n("Most Recently Played First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsTrack,
@@ -42,7 +45,10 @@ public:
                                                ElisaUtils::FilterByFrequentlyPlayed,
                                                ElisaUtils::Track,
                                                DataTypes::PlayFrequency,
+                                               {DataTypes::PlayFrequency},
+                                               {i18n("Play Frequency")},
                                                Qt::DescendingOrder,
+                                               {i18n("Least Frequently Played First"), i18n("Most Frequently Played First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsTrack,
@@ -53,6 +59,11 @@ public:
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Album,
+                                               DataTypes::TitleRole,
+                                               {DataTypes::TitleRole, DataTypes::ArtistRole, DataTypes::GenreRole, DataTypes::YearRole},
+                                               {i18n("Title"), i18n("Artist"), i18n("Genre"), i18n("Year")},
+                                               Qt::AscendingOrder,
+                                               {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("Oldest First"), i18n("Newest First")},
                                                QUrl{QStringLiteral("image://icon/media-optical-audio")},
                                                ViewManager::DelegateWithSecondaryText,
                                                ViewManager::ViewShowRating,
@@ -63,6 +74,11 @@ public:
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Artist,
+                                               Qt::DisplayRole,
+                                               {Qt::DisplayRole},
+                                               {i18n("Name")},
+                                               Qt::AscendingOrder,
+                                               {i18n("A-Z"), i18n("Z-A")},
                                                QUrl{QStringLiteral("image://icon/view-media-artist")},
                                                ViewManager::DelegateWithoutSecondaryText,
                                                ViewManager::ViewHideRating,
@@ -73,8 +89,15 @@ public:
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Track,
-                                               Qt::DisplayRole,
+                                               DataTypes::TitleRole,
+                                               {DataTypes::TitleRole, DataTypes::AlbumRole, DataTypes::ArtistRole,
+                                                DataTypes::GenreRole, DataTypes::YearRole, DataTypes::DurationRole,
+                                                DataTypes::ComposerRole, DataTypes::LyricistRole},
+                                               {i18n("Title"), i18n("Album"), i18n("Artist"), i18n("Genre"),
+                                                i18n("Year"), i18n("Duration"), i18n("Composer"), i18n("Lyricist")},
                                                Qt::AscendingOrder,
+                                               {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"),
+                                                i18n("Oldest First"), i18n("Newest First"), i18n("Shortest First"), i18n("Longest First"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsTrack,
@@ -85,6 +108,11 @@ public:
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Genre,
+                                               Qt::DisplayRole,
+                                               {Qt::DisplayRole},
+                                               {i18n("Genre")},
+                                               Qt::AscendingOrder,
+                                               {i18n("A-Z"), i18n("Z-A")},
                                                QUrl{QStringLiteral("image://icon/view-media-genre")},
                                                ViewManager::DelegateWithoutSecondaryText,
                                                ViewManager::ViewHideRating,
@@ -108,7 +136,10 @@ public:
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Radio,
                                                Qt::DisplayRole,
+                                               {Qt::DisplayRole},
+                                               {i18n("Name")},
                                                Qt::AscendingOrder,
+                                               {i18n("A-Z"), i18n("Z-A")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
                                                ViewManager::IsRadio,
@@ -127,6 +158,8 @@ public:
     MusicListenersManager *mManager = nullptr;
 
     DatabaseInterface *mDatabase = nullptr;
+
+    bool mIsFullyInitialized = true;
 };
 
 ViewsListData::ViewsListData(QObject *parent) : QObject(parent), d(std::make_unique<ViewsListDataPrivate>())
@@ -142,6 +175,11 @@ int ViewsListData::count() const
     return d->mViewsParameters.count();
 }
 
+bool ViewsListData::isEmpty() const
+{
+    return d->mViewsParameters.isEmpty();
+}
+
 const ViewParameters &ViewsListData::viewParameters(int index) const
 {
     return d->mViewsParameters[index];
@@ -223,10 +261,27 @@ void ViewsListData::setEmbeddedCategory(ElisaUtils::PlayListEntryType aEmbeddedV
         Q_EMIT embeddedCategoryChanged();
 
         refreshEmbeddedCategory();
+
+        switch (d->mEmbeddedCategory) {
+        case ElisaUtils::Composer:
+        case ElisaUtils::Container:
+        case ElisaUtils::FileName:
+        case ElisaUtils::Lyricist:
+        case ElisaUtils::Radio:
+        case ElisaUtils::Track:
+        case ElisaUtils::Unknown:
+            d->mIsFullyInitialized = true;
+            Q_EMIT isFullyInitializedChanged();
+            break;
+        case ElisaUtils::Album:
+        case ElisaUtils::Artist:
+        case ElisaUtils::Genre:
+            break;
+        }
     }
 }
 
-void ViewsListData::genresAdded(DataTypes::ListGenreDataType newData)
+void ViewsListData::genresAdded(const DataTypes::ListGenreDataType &newData)
 {
     if (d->mEmbeddedCategory != ElisaUtils::Genre) {
         return;
@@ -251,9 +306,12 @@ void ViewsListData::genresAdded(DataTypes::ListGenreDataType newData)
                                        ViewManager::ViewHideRating});
     }
     Q_EMIT dataAdded();
+
+    d->mIsFullyInitialized = true;
+    Q_EMIT isFullyInitializedChanged();
 }
 
-void ViewsListData::artistsAdded(DataTypes::ListArtistDataType newData)
+void ViewsListData::artistsAdded(const DataTypes::ListArtistDataType &newData)
 {
     if (d->mEmbeddedCategory != ElisaUtils::Artist) {
         return;
@@ -278,6 +336,9 @@ void ViewsListData::artistsAdded(DataTypes::ListArtistDataType newData)
                                        ViewManager::ViewShowRating});
     }
     Q_EMIT dataAdded();
+
+    d->mIsFullyInitialized = true;
+    Q_EMIT isFullyInitializedChanged();
 }
 
 void ViewsListData::artistRemoved(qulonglong removedDatabaseId)
@@ -298,7 +359,7 @@ void ViewsListData::artistRemoved(qulonglong removedDatabaseId)
     }
 }
 
-void ViewsListData::albumsAdded(DataTypes::ListAlbumDataType newData)
+void ViewsListData::albumsAdded(const DataTypes::ListAlbumDataType &newData)
 {
     if (d->mEmbeddedCategory != ElisaUtils::Album) {
         return;
@@ -326,13 +387,19 @@ void ViewsListData::albumsAdded(DataTypes::ListAlbumDataType newData)
                                        ElisaUtils::Track,
                                        ElisaUtils::Album,
                                        Qt::DisplayRole,
-                                       Qt::SortOrder::AscendingOrder,
+                                       {Qt::DisplayRole},
+                                       {QStringLiteral("Title")},
+                                       Qt::AscendingOrder,
+                                       {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
                                        ViewManager::SingleAlbum,
                                        ViewManager::DiscHeaders,
                                        ViewManager::IsTrack,
                                        useColorOverlay});
     }
     Q_EMIT dataAdded();
+
+    d->mIsFullyInitialized = true;
+    Q_EMIT isFullyInitializedChanged();
 }
 
 void ViewsListData::albumRemoved(qulonglong removedDatabaseId)
@@ -494,6 +561,11 @@ void ViewsListData::refreshEmbeddedCategory()
                                        ViewManager::GenericDataModel,
                                        ElisaUtils::NoFilter,
                                        ElisaUtils::Album,
+                                       Qt::DisplayRole,
+                                       {DataTypes::TitleRole, DataTypes::ArtistRole, DataTypes::GenreRole, DataTypes::YearRole},
+                                       {i18n("Title"), i18n("Artist"), i18n("Genre"), i18n("Year")},
+                                       Qt::AscendingOrder,
+                                       {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("Oldest First"), i18n("Newest First")},
                                        QUrl{QStringLiteral("image://icon/media-optical-audio")},
                                        ViewManager::DelegateWithSecondaryText,
                                        ViewManager::ViewShowRating,
@@ -508,6 +580,11 @@ void ViewsListData::refreshEmbeddedCategory()
                                        ViewManager::GenericDataModel,
                                        ElisaUtils::NoFilter,
                                        ElisaUtils::Artist,
+                                       Qt::DisplayRole,
+                                       {Qt::DisplayRole},
+                                       {i18n("Name")},
+                                       Qt::AscendingOrder,
+                                       {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
                                        QUrl{QStringLiteral("image://icon/view-media-artist")},
                                        ViewManager::DelegateWithoutSecondaryText,
                                        ViewManager::ViewHideRating,
@@ -522,6 +599,11 @@ void ViewsListData::refreshEmbeddedCategory()
                                        ViewManager::GenericDataModel,
                                        ElisaUtils::NoFilter,
                                        ElisaUtils::Genre,
+                                       Qt::DisplayRole,
+                                       {Qt::DisplayRole},
+                                       {i18n("Genre")},
+                                       Qt::AscendingOrder,
+                                       {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
                                        QUrl{QStringLiteral("image://icon/view-media-genre")},
                                        ViewManager::DelegateWithoutSecondaryText,
                                        ViewManager::ViewHideRating,
@@ -559,6 +641,11 @@ DatabaseInterface* ViewsListData::database() const
     return d->mDatabase;
 }
 
+bool ViewsListData::isFullyInitialized() const
+{
+    return d->mIsFullyInitialized;
+}
+
 void ViewsListData::setDatabase(DatabaseInterface *aDatabase)
 {
     if (d->mDatabase != aDatabase) {
